==> packageinstaller-pkglist-libre_0.1.6.tar.xz: packageinstaller-pkglist-libre/Esperanto_Default_Firefox_esr.pm <==
<?xml version="1.0"?>
<app>

<category>
Language
</category>

<name>
Esperanto_Default_Firefox_esr
</name>

<description>
   <am>Esperanto localisation of Firefox ESR</am>
   <ar>Esperanto localisation of Firefox ESR</ar>
   <be>Esperanto localisation of Firefox ESR</be>
   <bg>Esperanto localisation of Firefox ESR</bg>
   <bn>Esperanto localisation of Firefox ESR</bn>
   <ca>Esperanto localisation of Firefox ESR</ca>
   <cs>Esperanto localisation of Firefox ESR</cs>
   <da>Esperanto localisation of Firefox ESR</da>
   <de>Lokalisation für “Esperanto” von “Firefox ESR”</de>
   <el>Esperanto για Firefox ESR</el>
   <en>Esperanto localisation of Firefox ESR</en>
   <es_ES>Esperanto localisation of Firefox ESR</es_ES>
   <es>Localización Esperanto de Firefox ESR</es>
   <et>Esperanto localisation of Firefox ESR</et>
   <eu>Esperanto localisation of Firefox ESR</eu>
   <fa>Esperanto localisation of Firefox ESR</fa>
   <fil_PH>Esperanto localisation of Firefox ESR</fil_PH>
   <fi>Esperanto localisation of Firefox ESR</fi>
   <fr_BE>Esperanto localisation of Firefox ESR</fr_BE>
   <fr>Localisation en espéranto de Firefox ESR</fr>
   <gl_ES>Esperanto localisation of Firefox ESR</gl_ES>
   <he_IL>Esperanto localisation of Firefox ESR</he_IL>
   <hi>Esperanto localisation of Firefox ESR</hi>
   <hr>Esperanto localisation of Firefox ESR</hr>
   <hu>Esperanto localisation of Firefox ESR</hu>
   <id>Esperanto localisation of Firefox ESR</id>
   <is>Esperanto localisation of Firefox ESR</is>
   <it>Esperanto localisation of Firefox ESR</it>
   <ja>エスペラント語版 Firefox ESR</ja>
   <kk>Esperanto localisation of Firefox ESR</kk>
   <ko>Esperanto localisation of Firefox ESR</ko>
   <lt>Esperanto localisation of Firefox ESR</lt>
   <mk>Esperanto localisation of Firefox ESR</mk>
   <mr>Esperanto localisation of Firefox ESR</mr>
   <nb_NO>Esperanto localisation of Firefox ESR</nb_NO>
   <nb>Esperanto lokaltilpassing av Firefox ESR</nb>
   <nl_BE>Esperanto localisation of Firefox ESR</nl_BE>
   <nl>Esperanto localisation of Firefox ESR</nl>
   <pl>Esperanto localisation of Firefox ESR</pl>
   <pt_BR>Esperanto Localização para o Firefox ESR</pt_BR>
   <pt>Esperanto localisation of Firefox ESR</pt>
   <ro>Esperanto localisation of Firefox ESR</ro>
   <ru>Esperanto localisation of Firefox ESR</ru>
   <sk>Esperanto localisation of Firefox ESR</sk>
   <sl>Esperanto localisation of Firefox ESR</sl>
   <sq>Esperanto localisation of Firefox ESR</sq>
   <sr>Esperanto localisation of Firefox ESR</sr>
   <sv>Esperanto lokalisering av Firefox ESR</sv>
   <th>Esperanto localisation of Firefox ESR</th>
   <tr>Esperanto localisation of Firefox ESR</tr>
   <uk>Esperanto localisation of Firefox ESR</uk>
   <vi>Esperanto localisation of Firefox ESR</vi>
   <zh_CN>Esperanto localisation of Firefox ESR</zh_CN>
   <zh_HK>Esperanto localisation of Firefox ESR</zh_HK>
   <zh_TW>Esperanto localisation of Firefox ESR</zh_TW>
</description>

<installable>
all
</installable>

<screenshot>none</screenshot>

<preinstall>
</preinstall>

<install_package_names>
firefox-esr-l10n-eo
</install_package_names>

<postinstall>

</postinstall>

<uninstall_package_names>
firefox-esr-l10n-eo
</uninstall_package_names>

</app>

==> packageinstaller-pkglist-libre_0.1.7.tar.xz: packageinstaller-pkglist-libre/Esperanto_Default_Firefox_esr.pm <==
<?xml version="1.0"?>
<app>

<category>
Language
</category>

<name>
Esperanto_Default_Firefox_esr
</name>

<description>
   <am>Esperanto localisation of Firefox ESR</am>
   <ar>Esperanto localisation of Firefox ESR</ar>
   <be>Esperanto localisation of Firefox ESR</be>
   <bg>Esperanto localisation of Firefox ESR</bg>
   <bn>Esperanto localisation of Firefox ESR</bn>
   <ca>Esperanto localisation of Firefox ESR</ca>
   <cs>Esperanto localisation of Firefox ESR</cs>
   <da>Esperanto localisation of Firefox ESR</da>
   <de>Lokalisation für “Esperanto” von “Firefox ESR”</de>
   <el>Esperanto για Firefox ESR</el>
   <en>Esperanto localisation of Firefox ESR</en>
   <es_ES>Esperanto localisation of Firefox ESR</es_ES>
   <es>Localización Esperanto de Firefox ESR</es>
   <et>Esperanto localisation of Firefox ESR</et>
   <eu>Esperanto localisation of Firefox ESR</eu>
   <fa>Esperanto localisation of Firefox ESR</fa>
   <fil_PH>Esperanto localisation of Firefox ESR</fil_PH>
   <fi>Esperanto localisation of Firefox ESR</fi>
   <fr_BE>Localisation en espéranto de Firefox ESR</fr_BE>
   <fr>Localisation en espéranto de Firefox ESR</fr>
   <gl_ES>Esperanto localisation of Firefox ESR</gl_ES>
   <he_IL>Esperanto localisation of Firefox ESR</he_IL>
   <hi>Esperanto localisation of Firefox ESR</hi>
   <hr>Esperanto localisation of Firefox ESR</hr>
   <hu>Esperanto localisation of Firefox ESR</hu>
   <id>Esperanto localisation of Firefox ESR</id>
   <is>Esperanto localisation of Firefox ESR</is>
   <it>Esperanto localisation of Firefox ESR</it>
   <ja>エスペラント語版 Firefox ESR</ja>
   <kk>Esperanto localisation of Firefox ESR</kk>
   <ko>Esperanto localisation of Firefox ESR</ko>
   <lt>Esperanto localisation of Firefox ESR</lt>
   <mk>Esperanto localisation of Firefox ESR</mk>
   <mr>Esperanto localisation of Firefox ESR</mr>
   <nb_NO>Esperanto localisation of Firefox ESR</nb_NO>
   <nb>Esperanto lokaltilpassing av Firefox ESR</nb>
   <nl_BE>Esperanto localisation of Firefox ESR</nl_BE>
   <nl>Esperanto localisation of Firefox ESR</nl>
   <pl>Esperanto localisation of Firefox ESR</pl>
   <pt_BR>Esperanto Localização para o Firefox ESR</pt_BR>
   <pt>Esperanto localisation of Firefox ESR</pt>
   <ro>Esperanto localisation of Firefox ESR</ro>
   <ru>Esperanto localisation of Firefox ESR</ru>
   <sk>Esperanto localisation of Firefox ESR</sk>
   <sl>Esperanto localisation of Firefox ESR</sl>
   <sq>Esperanto localisation of Firefox ESR</sq>
   <sr>Esperanto localisation of Firefox ESR</sr>
   <sv>Esperanto lokalisering av Firefox ESR</sv>
   <th>Esperanto localisation of Firefox ESR</th>
   <tr>Esperanto localisation of Firefox ESR</tr>
   <uk>Esperanto localisation of Firefox ESR</uk>
   <vi>Esperanto localisation of Firefox ESR</vi>
   <zh_CN>Esperanto localisation of Firefox ESR</zh_CN>
   <zh_HK>Esperanto localisation of Firefox ESR</zh_HK>
   <zh_TW>Esperanto localisation of Firefox ESR</zh_TW>
</description>

<installable>
all
</installable>

<screenshot>none</screenshot>

<preinstall>
</preinstall>

<install_package_names>
firefox-esr-l10n-eo
</install_package_names>

<postinstall>

</postinstall>

<uninstall_package_names>
firefox-esr-l10n-eo
</uninstall_package_names>

</app>
